@@ -3,9 +3,10 @@ from .core import (
     AzureBlobHandler,
     LocalFileHandler,
     NullHandler,
+    PersistentDict,
     PersistentJSON,
     ResultCollector,
 )
-from .datamanage import DrioDataSource
+from .datamanage import CompositeDataSource, DrioDataSource, NullDataSource
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
